@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -137,6 +137,8 @@ __PACKAGE__->add_property( 'alien_stage_install' => 1 );
 # For now this will default to off.  See gh#119 for a discussion.
 __PACKAGE__->add_property( 'alien_arch' => defined $ENV{ALIEN_ARCH} ? $ENV{ALIEN_ARCH} : 0 );
 
+__PACKAGE__->add_property( 'alien_helper' => {} );
+
 ################
 #  ConfigData  #
 ################
@@ -240,6 +242,9 @@ END
 sub ACTION_alien_fakebuild {
   my $self = shift;
 
+  # needed for any helpers provided by alien_bin_requires
+  $self->_alien_bin_require($_) for keys %{ $self->alien_bin_requires };
+
   print "# Build\n";
   foreach my $cmd (@{ $self->alien_build_commands })
   {
@@ -327,6 +332,12 @@ sub ACTION_alien_code {
   if ($version) {
     $self->config_data( install_type => 'system' );
     $self->config_data( version => $version );
+    my %system_provides;
+    $system_provides{Cflags} = $self->alien_provides_cflags
+      if defined $self->alien_provides_cflags;
+    $system_provides{Libs}   = $self->alien_provides_libs
+      if defined $self->alien_provides_libs;
+    $self->config_data( system_provides => \%system_provides );
     return;
   }
 
@@ -646,6 +657,23 @@ sub _filter_defines
   join ' ', grep !/^-D/, shellwords($_[0]);
 }
 
+sub _alien_bin_require {
+  my($self, $mod) = @_;
+  
+  my $version = $self->alien_bin_requires->{$mod};
+
+  eval qq{ use $mod $version () }; # should also work for version = 0
+  die $@ if $@;
+  
+  if($mod->can('alien_helper')) {
+    my $helpers = $mod->alien_helper;
+    while(my($k,$v) = each %$helpers) {
+      next if defined $self->alien_helper->{$k};
+      $self->alien_helper->{$k} = $v;
+    }
+  }
+}
+
 sub _env_do_system {
   my $self = shift;
   my $command = shift;
@@ -659,9 +687,7 @@ sub _env_do_system {
   my $config;
   
   foreach my $mod (keys %{ $self->alien_bin_requires }) {
-    my $version = $self->alien_bin_requires->{$mod};
-    eval qq{ use $mod $version () }; # should also work for version = 0
-    die $@ if $@;
+    $self->_alien_bin_require($mod);
     
     my %path;
     
@@ -797,6 +823,23 @@ sub do_system {
   return wantarray ? %return : $return{success};
 }
 
+sub _alien_execute_helper {
+  my($self, $helper) = @_;
+  my $code = $self->alien_helper->{$helper};
+  die "no such helper: $helper" unless defined $code;
+
+  if(ref($code) ne 'CODE') {
+    my $perl = $code;
+    $code = sub {
+      my $value = eval $perl;
+      die $@ if $@;
+      $value;
+    };
+  }
+
+  $code->();
+}
+
 sub alien_interpolate {
   my $self = shift;
   my ($string) = @_;
@@ -830,6 +873,8 @@ sub alien_interpolate {
     }
   }
 
+  $string =~ s/(?<!\%)\%\{([a-zA-Z_][a-zA-Z_0-9]+)\}/$self->_alien_execute_helper($1)/eg;
+
   #remove escapes (%%)
   $string =~ s/\%(?=\%)//g;
 
